Package: StratPal
Title: Stratigraphic Paleobiology Modeling Pipelines
Version: 0.3.1
Authors@R: 
    person("Niklas", "Hohmann", , "N.H.Hohmann@uu.nl", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0003-1559-1838"))
Description: The fossil record is a joint expression of ecological, taphonomic, 
    evolutionary, and stratigraphic processes (Holland and Patzkowsky, 2012, ISBN:978-0226649382).
    This package allowing to simulate biological processes in the time domain
    (e.g., trait evolution, fossil abundance), and examine how their expression
    in the rock record (stratigraphic domain) is influenced based on 
    age-depth models, ecological niche models, and taphonomic effects.
    Functions simulating common processes used in modeling trait evolution or 
    event type data such as first/last occurrences are provided and can be used 
    standalone or as part of a pipeline. The package comes with example 
    data sets and tutorials in several vignettes, which can be used as a 
    template to set up one's own simulation.
License: Apache License (>= 2)
Encoding: UTF-8
RoxygenNote: 7.3.2
Imports: admtools (>= 0.4.0), paleoTS
Suggests: knitr, rmarkdown, spelling, testthat (>= 3.0.0)
VignetteBuilder: knitr
Depends: R (>= 4.2)
LazyData: true
URL: https://mindthegap-erc.github.io/StratPal/ ,
        https://github.com/MindTheGap-ERC/StratPal
BugReports: https://github.com/MindTheGap-ERC/StratPal/issues
Config/testthat/edition: 3
Language: en-US
NeedsCompilation: no
Packaged: 2025-02-20 11:26:43 UTC; hohma004
Author: Niklas Hohmann [aut, cre] (<https://orcid.org/0000-0003-1559-1838>)
Maintainer: Niklas Hohmann <N.H.Hohmann@uu.nl>
Repository: CRAN
Date/Publication: 2025-02-20 11:40:02 UTC
Built: R 4.5.0; ; 2025-02-20 12:57:49 UTC; unix
