# Generated by roxygen2: do not edit by hand

S3method(apply_niche,char_mat)
S3method(apply_niche,fossils)
S3method(apply_niche,numeric)
S3method(apply_niche,pre_paleoTS)
S3method(apply_taphonomy,char_mat)
S3method(apply_taphonomy,fossils)
S3method(apply_taphonomy,numeric)
S3method(apply_taphonomy,pre_paleoTS)
S3method(plot,pre_paleoTS)
S3method(reduce_to_paleoTS,pre_paleoTS)
export(all_preserved)
export(apply_niche)
export(apply_taphonomy)
export(as_char_mat)
export(bounded_niche)
export(discrete_gradient)
export(discrete_niche)
export(gradient_from_data)
export(is_char_mat)
export(last_occ)
export(ornstein_uhlenbeck)
export(ornstein_uhlenbeck_sl)
export(p3)
export(p3_var_rate)
export(perfect_preservation)
export(prob_remove)
export(random_walk)
export(random_walk_sl)
export(range_offset)
export(reduce_to_paleoTS)
export(rej_samp)
export(snd_niche)
export(stasis)
export(stasis_sl)
export(strat_filter)
export(strict_stasis_sl)
export(thin)
export(trivial_gradient)
export(trivial_niche)
